@@ -1,6 +1,7 @@
 """jc - JSON Convert `vmstat` command output streaming parser
 
-> This streaming parser outputs JSON Lines
+> This streaming parser outputs JSON Lines (cli) or returns an Iterable of
+  Dictionaries (module)
 
 Options supported: `-a`, `-w`, `-d`, `-t`
 
@@ -15,28 +16,20 @@ Usage (cli):
     $ vmstat | jc --vmstat-s
 
 > Note: When piping `jc` converted `vmstat` output to other processes it may
-appear the output is hanging due to the OS pipe buffers. This is because
-`vmstat` output is too small to quickly fill up the buffer. Use the `-u`
-option to unbuffer the `jc` output if you would like immediate output. See
-the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
-for more information.
+  appear the output is hanging due to the OS pipe buffers. This is because
+  `vmstat` output is too small to quickly fill up the buffer. Use the `-u`
+  option to unbuffer the `jc` output if you would like immediate output. See
+  the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
+  for more information.
 
 Usage (module):
 
     import jc
-    # result is an iterable object (generator)
+
     result = jc.parse('vmstat_s', vmstat_command_output.splitlines())
     for item in result:
         # do something
 
-    or
-
-    import jc.parsers.vmstat_s
-    # result is an iterable object (generator)
-    result = jc.parsers.vmstat_s.parse(vmstat_command_output.splitlines())
-    for item in result:
-        # do something
-
 Schema:
 
     {
@@ -75,14 +68,12 @@ Schema:
       "epoch":                            integer,     # [0]
       "epoch_utc":                        integer      # [1]
 
-      # Below object only exists if using -qq or ignore_exceptions=True
-
-      "_jc_meta":
-        {
-          "success":                      boolean,  # [2]
-          "error":                        string,   # [3]
-          "line":                         string    # [3]
-        }
+      # below object only exists if using -qq or ignore_exceptions=True
+      "_jc_meta": {
+        "success":                        boolean,  # [2]
+        "error":                          string,   # [3]
+        "line":                           string    # [3]
+      }
     }
 
     [0] naive timestamp if -t flag is used
@@ -156,7 +147,7 @@ def _process(proc_data):
 @add_jc_meta
 def parse(data, raw=False, quiet=False, ignore_exceptions=False):
     """
-    Main text parsing generator function. Returns an iterator object.
+    Main text parsing generator function. Returns an iterable object.
 
     Parameters:
 
@@ -167,13 +158,9 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
         quiet:             (boolean)   suppress warning messages if True
         ignore_exceptions: (boolean)   ignore parsing exceptions if True
 
-    Yields:
-
-        Dictionary. Raw or processed structured data.
-
     Returns:
 
-        Iterator object (generator)
+        Iterable of Dictionaries
     """
     jc.utils.compatibility(__name__, info.compatible, quiet)
     streaming_input_type_check(data)
